@@ -1,31 +1,35 @@
 from copy import deepcopy
 
+from django import forms
 from django.db.models import Q
 from django.test import TestCase, tag
 from edc_constants.constants import (
     HEADACHE,
+    IN_PERSON,
     NO,
-    NONE,
     NOT_APPLICABLE,
     OTHER,
+    TELEPHONE,
     UNKNOWN,
     VISUAL_LOSS,
     YES,
 )
-from edc_csf.constants import (
+from edc_constants.disease_constants import (
     CN_PALSY_LEFT_OTHER,
     CN_PALSY_RIGHT_OTHER,
     FOCAL_NEUROLOGIC_DEFICIT_OTHER,
 )
 from model_bakery import baker
 
-from effect_lists.models import BloodTests, SiSx
+from effect_lists.models import SiSx
 from effect_screening.tests.effect_test_case_mixin import EffectTestCaseMixin
 from effect_subject.forms import SignsAndSymptomsForm
 from effect_subject.forms.signs_and_symptoms_form import SignsAndSymptomsFormValidator
 from effect_subject.tests.tests.mixins import ReportingFieldsetBaselineTestCaseMixin
 from effect_visit_schedule.constants import DAY01, DAY14
 
+# TODO: Migrate to effect-form-validator
+
 
 @tag("sas")
 class TestSignsAndSymptoms(EffectTestCaseMixin, TestCase):
@@ -49,65 +53,81 @@ class TestSignsAndSymptomsFormValidationBase(EffectTestCaseMixin, TestCase):
         super().setUp()
         self.subject_visit = self.get_subject_visit()
 
-    def get_valid_patient_with_no_signs_or_symptoms(self, visit_code: str = None):
+    def get_valid_patient_with_no_signs_or_symptoms(
+        self,
+        visit_code: str = None,
+        assessment_type: str = None,
+    ):
         self.subject_visit.appointment.visit_code = visit_code or DAY14
+        self.subject_visit.assessment_type = assessment_type or IN_PERSON
         return {
             "subject_visit": self.subject_visit,
-            # "appointment": self.subject_visit.appointment,
             "report_datetime": self.subject_visit.report_datetime,
             "any_sx": NO,
-            "current_sx": SiSx.objects.filter(name=NONE),
+            "current_sx": SiSx.objects.filter(name=NOT_APPLICABLE),
             "current_sx_other": "",
-            "current_sx_gte_g3": SiSx.objects.filter(name=NONE),
+            "cm_sx": NOT_APPLICABLE,
+            "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
             "current_sx_gte_g3_other": "",
             "headache_duration": "",
             "cn_palsy_left_other": "",
             "cn_palsy_right_other": "",
             "focal_neurologic_deficit_other": "",
             "visual_field_loss": "",
+            "xray_performed": NOT_APPLICABLE if assessment_type == TELEPHONE else NO,
+            "lp_performed": NOT_APPLICABLE if assessment_type == TELEPHONE else NO,
+            "urinary_lam_performed": NOT_APPLICABLE if assessment_type == TELEPHONE else NO,
             "reportable_as_ae": NOT_APPLICABLE,
             "patient_admitted": NOT_APPLICABLE,
-            "cm_sx": NOT_APPLICABLE,
-            "cm_sx_lp_done": NOT_APPLICABLE,
-            "cm_sx_bloods_take": BloodTests.objects.filter(name=NOT_APPLICABLE),
-            "cm_sx_bloods_taken_other": "",
         }
 
     def get_valid_patient_any_sx_unknown(self, visit_code: str = None):
         cleaned_data = deepcopy(
-            self.get_valid_patient_with_no_signs_or_symptoms(visit_code=visit_code)
+            self.get_valid_patient_with_no_signs_or_symptoms(
+                visit_code=visit_code, assessment_type=TELEPHONE
+            )
         )
         cleaned_data.update(
             {
                 "any_sx": UNKNOWN,
                 "current_sx": SiSx.objects.filter(name=NOT_APPLICABLE),
                 "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
+                # Cannot be in person visit if "any_sx": UNKNOWN
+                # Investigations cannot have been performed if not in person visit
+                "xray_performed": NOT_APPLICABLE,
+                "lp_performed": NOT_APPLICABLE,
+                "urinary_lam_performed": NOT_APPLICABLE,
             }
         )
         return cleaned_data
 
-    def get_valid_patient_with_signs_or_symptoms(self, visit_code: str = None):
+    def get_valid_patient_with_signs_or_symptoms(
+        self,
+        visit_code: str = None,
+        assessment_type: str = None,
+    ):
         self.subject_visit.appointment.visit_code = visit_code or DAY14
+        self.subject_visit.assessment_type = assessment_type or IN_PERSON
+
         return {
             "subject_visit": self.subject_visit,
-            # "appointment": self.subject_visit.appointment,
             "report_datetime": self.subject_visit.report_datetime,
             "any_sx": YES,
             "current_sx": SiSx.objects.filter(Q(name="fever") | Q(name="vomiting")),
             "current_sx_other": "",
-            "current_sx_gte_g3": SiSx.objects.filter(name=NONE),
+            "cm_sx": NO,
+            "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
             "current_sx_gte_g3_other": "",
             "headache_duration": "",
             "cn_palsy_left_other": "",
             "cn_palsy_right_other": "",
             "focal_neurologic_deficit_other": "",
             "visual_field_loss": "",
+            "xray_performed": YES,
+            "lp_performed": YES,
+            "urinary_lam_performed": YES,
             "reportable_as_ae": NOT_APPLICABLE if visit_code == DAY01 else NO,
             "patient_admitted": NOT_APPLICABLE if visit_code == DAY01 else NO,
-            "cm_sx": NO,
-            "cm_sx_lp_done": NOT_APPLICABLE,
-            "cm_sx_bloods_taken": BloodTests.objects.filter(name=NOT_APPLICABLE),
-            "cm_sx_bloods_taken_other": "",
         }
 
     def get_valid_patient_with_g3_signs_or_symptoms(self, visit_code: str = None):
@@ -127,26 +147,9 @@ class TestSignsAndSymptomsFormValidationBase(EffectTestCaseMixin, TestCase):
         cleaned_data = deepcopy(
             self.get_valid_patient_with_g3_signs_or_symptoms(visit_code=visit_code)
         )
-        cleaned_data.update(
-            {
-                "cm_sx": YES,
-                "cm_sx_lp_done": YES,
-                "cm_sx_bloods_taken": BloodTests.objects.filter(
-                    Q(name="chemistry") | Q(name="hematology")
-                ),
-                "cm_sx_bloods_taken_other": "",
-            }
-        )
+        cleaned_data.update({"cm_sx": YES})
         return cleaned_data
 
-    @staticmethod
-    def get_non_yes_sx_selection(any_sx_answer: str):
-        return (
-            SiSx.objects.filter(name=NONE)
-            if any_sx_answer == NO
-            else SiSx.objects.filter(name=NOT_APPLICABLE)
-        )
-
 
 @tag("sas")
 class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase):
@@ -210,7 +213,7 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
             form_validator=self.validate_form_validator(cleaned_data)
         )
 
-    def test_m2m_sx_selections_expect_none_if_any_sx_is_no(self):
+    def test_m2m_sx_selections_expect_na_if_any_sx_is_no(self):
         cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms()
         cleaned_data.update(
             {
@@ -221,23 +224,23 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
         )
         self.assertFormValidatorError(
             field="current_sx",
-            expected_msg="Expected '--No symptoms to report' only.",
+            expected_msg="Expected '--Not applicable' only.",
             form_validator=self.validate_form_validator(cleaned_data),
         )
 
         cleaned_data.update(
             {
-                "current_sx": SiSx.objects.filter(name=NONE),
+                "current_sx": SiSx.objects.filter(name=NOT_APPLICABLE),
                 "current_sx_gte_g3": SiSx.objects.filter(name="fever"),
             }
         )
         self.assertFormValidatorError(
             field="current_sx_gte_g3",
-            expected_msg="Expected '--No symptoms to report' only.",
+            expected_msg="Expected '--Not applicable' only.",
             form_validator=self.validate_form_validator(cleaned_data),
         )
 
-        cleaned_data.update({"current_sx_gte_g3": SiSx.objects.filter(name=NONE)})
+        cleaned_data.update({"current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE)})
         self.assertFormValidatorNoError(self.validate_form_validator(cleaned_data))
 
     def test_m2m_sx_selections_expect_na_if_any_sx_is_unknown(self):
@@ -251,7 +254,7 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
         )
         self.assertFormValidatorError(
             field="current_sx",
-            expected_msg="Expected '--Not applicable (if signs or symptoms 'Unknown')' only.",
+            expected_msg="Expected '--Not applicable' only.",
             form_validator=self.validate_form_validator(cleaned_data),
         )
 
@@ -263,50 +266,53 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
         )
         self.assertFormValidatorError(
             field="current_sx_gte_g3",
-            expected_msg="Expected '--Not applicable (if signs or symptoms 'Unknown')' only.",
+            expected_msg="Expected '--Not applicable' only.",
             form_validator=self.validate_form_validator(cleaned_data),
         )
 
         cleaned_data.update({"current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE)})
         self.assertFormValidatorNoError(self.validate_form_validator(cleaned_data))
 
-    def test_m2m_current_sx_with_na_and_none_invalid_if_any_sx_is_yes(self):
+    def test_m2m_current_sx_with_na_invalid_if_any_sx_is_yes(self):
         cleaned_data = self.get_valid_patient_with_signs_or_symptoms()
         cleaned_data.update(
             {
                 "any_sx": YES,
-                "current_sx": SiSx.objects.filter(
-                    Q(name="fever") | Q(name=NONE) | Q(name=NOT_APPLICABLE)
-                ),
-            }
-        )
-        self.assertFormValidatorError(
-            field="current_sx",
-            expected_msg=(
-                "Invalid selection. Cannot be any of: "
-                "--No symptoms to report, --Not applicable (if signs or symptoms 'Unknown')."
-            ),
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update(
-            {
                 "current_sx": SiSx.objects.filter(Q(name="fever") | Q(name=NOT_APPLICABLE)),
             }
         )
         self.assertFormValidatorError(
             field="current_sx",
-            expected_msg=(
-                "Invalid selection. Cannot be any of: "
-                "--Not applicable (if signs or symptoms 'Unknown')."
-            ),
+            expected_msg="Invalid selection. Cannot be any of: --Not applicable.",
+            form_validator=self.validate_form_validator(cleaned_data),
+        )
+
+        cleaned_data.update(
+            {
+                "current_sx": SiSx.objects.filter(Q(name=NOT_APPLICABLE)),
+            }
+        )
+        self.assertFormValidatorError(
+            field="current_sx",
+            expected_msg="Invalid selection. Cannot be any of: --Not applicable.",
             form_validator=self.validate_form_validator(cleaned_data),
         )
 
         cleaned_data.update({"current_sx": SiSx.objects.filter(Q(name="fever"))})
         self.assertFormValidatorNoError(self.validate_form_validator(cleaned_data))
 
-    def test_m2m_current_sx_gte_g3_with_na_invalid_if_any_sx_is_yes(self):
+    def test_m2m_current_sx_gte_g3_can_be_na_if_any_sx_is_yes(self):
+        cleaned_data = self.get_valid_patient_with_g3_signs_or_symptoms()
+        cleaned_data.update(
+            {
+                "any_sx": YES,
+                "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
+                "reportable_as_ae": NO,
+            }
+        )
+        self.assertFormValidatorNoError(self.validate_form_validator(cleaned_data))
+
+    def test_m2m_current_sx_gte_g3_cannot_be_na_with_another_selection(self):
         cleaned_data = self.get_valid_patient_with_g3_signs_or_symptoms()
         cleaned_data.update(
             {
@@ -316,44 +322,11 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
                 ),
             }
         )
-        self.assertFormValidatorError(
-            field="current_sx_gte_g3",
-            expected_msg=(
-                "Invalid selection. Cannot be any of: "
-                "--Not applicable (if signs or symptoms 'Unknown')."
-            ),
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update({"current_sx_gte_g3": SiSx.objects.filter(Q(name="fever"))})
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data)
-        )
-
-    def test_m2m_current_sx_gte_g3_can_be_none_if_any_sx_is_yes(self):
-        cleaned_data = self.get_valid_patient_with_g3_signs_or_symptoms()
-        cleaned_data.update(
-            {
-                "any_sx": YES,
-                "current_sx_gte_g3": SiSx.objects.filter(name=NONE),
-                "reportable_as_ae": NO,
-            }
-        )
-        self.assertFormValidatorNoError(self.validate_form_validator(cleaned_data))
-
-    def test_m2m_current_sx_gte_g3_cannot_be_none_with_another_selection(self):
-        cleaned_data = self.get_valid_patient_with_g3_signs_or_symptoms()
-        cleaned_data.update(
-            {
-                "any_sx": YES,
-                "current_sx_gte_g3": SiSx.objects.filter(Q(name="fever") | Q(name=NONE)),
-            }
-        )
         self.assertFormValidatorError(
             field="current_sx_gte_g3",
             expected_msg=(
                 "Invalid combination. "
-                "'--No symptoms to report' may not be combined with other selections"
+                "'--Not applicable' may not be combined with other selections"
             ),
             form_validator=self.validate_form_validator(cleaned_data),
         )
@@ -363,7 +336,7 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
 
         cleaned_data.update(
             {
-                "current_sx_gte_g3": SiSx.objects.filter(Q(name=NONE)),
+                "current_sx_gte_g3": SiSx.objects.filter(Q(name=NOT_APPLICABLE)),
                 "reportable_as_ae": NO,
             }
         )
@@ -454,7 +427,7 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
                     {
                         "current_sx_gte_g3": SiSx.objects.filter(name="fever")
                         if answer == YES
-                        else SiSx.objects.filter(name=NONE),
+                        else SiSx.objects.filter(name=NOT_APPLICABLE),
                         "reportable_as_ae": answer,
                     }
                 )
@@ -469,12 +442,14 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
                     any_sx_answer=any_sx_answer,
                     reportable_as_ae_answer=reportable_as_ae_answer,
                 ):
-                    cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms()
+                    cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms(
+                        assessment_type=TELEPHONE if any_sx_answer == UNKNOWN else IN_PERSON
+                    )
                     cleaned_data.update(
                         {
                             "any_sx": any_sx_answer,
-                            "current_sx": self.get_non_yes_sx_selection(any_sx_answer),
-                            "current_sx_gte_g3": self.get_non_yes_sx_selection(any_sx_answer),
+                            "current_sx": SiSx.objects.filter(name=NOT_APPLICABLE),
+                            "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
                             "reportable_as_ae": reportable_as_ae_answer,
                         }
                     )
@@ -522,7 +497,7 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
         cleaned_data = self.get_valid_patient_with_signs_or_symptoms()
         cleaned_data.update(
             {
-                "current_sx_gte_g3": SiSx.objects.filter(name=NONE),
+                "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
                 "reportable_as_ae": NOT_APPLICABLE,
             }
         )
@@ -547,7 +522,7 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
             form_validator=self.validate_form_validator(cleaned_data)
         )
 
-    def test_reportable_as_ae_yes_invalid_if_sx_gte_g3_none(self):
+    def test_reportable_as_ae_yes_invalid_if_sx_gte_g3_na(self):
         cleaned_data = self.get_valid_patient_with_signs_or_symptoms()
         cleaned_data.update({"reportable_as_ae": YES})
         self.assertFormValidatorError(
@@ -581,9 +556,9 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
             form_validator=self.validate_form_validator(cleaned_data)
         )
 
-    def test_current_sx_gte_g3_not_required_if_any_sx_is_yes(self):
+    def test_can_opt_out_of_current_sx_gte_g3_if_any_sx_is_yes(self):
         cleaned_data = self.get_valid_patient_with_signs_or_symptoms()
-        cleaned_data.update({"current_sx_gte_g3": SiSx.objects.filter(name=NONE)})
+        cleaned_data.update({"current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE)})
 
         self.assertFormValidatorNoError(
             form_validator=self.validate_form_validator(cleaned_data),
@@ -594,17 +569,17 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
         cleaned_data.update(
             {
                 "any_sx": NO,
-                "current_sx": SiSx.objects.filter(name=NONE),
+                "current_sx": SiSx.objects.filter(name=NOT_APPLICABLE),
                 "current_sx_gte_g3": SiSx.objects.filter(name="fever"),
             }
         )
         self.assertFormValidatorError(
             field="current_sx_gte_g3",
-            expected_msg="Expected '--No symptoms to report' only.",
+            expected_msg="Expected '--Not applicable' only.",
             form_validator=self.validate_form_validator(cleaned_data),
         )
 
-        cleaned_data.update({"current_sx_gte_g3": SiSx.objects.filter(name=NONE)})
+        cleaned_data.update({"current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE)})
         self.assertFormValidatorNoError(
             form_validator=self.validate_form_validator(cleaned_data)
         )
@@ -823,12 +798,14 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
                     any_sx_answer=any_sx_answer,
                     patient_admitted_answer=patient_admitted_answer,
                 ):
-                    cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms()
+                    cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms(
+                        assessment_type=TELEPHONE if any_sx_answer == UNKNOWN else IN_PERSON
+                    )
                     cleaned_data.update(
                         {
                             "any_sx": any_sx_answer,
-                            "current_sx": self.get_non_yes_sx_selection(any_sx_answer),
-                            "current_sx_gte_g3": self.get_non_yes_sx_selection(any_sx_answer),
+                            "current_sx": SiSx.objects.filter(name=NOT_APPLICABLE),
+                            "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
                             "patient_admitted": patient_admitted_answer,
                         }
                     )
@@ -861,13 +838,6 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
             with self.subTest(answer=answer):
                 cleaned_data = self.get_valid_patient_with_signs_or_symptoms()
                 cleaned_data.update({"cm_sx": answer})
-                if answer == YES:
-                    cleaned_data.update(
-                        {
-                            "cm_sx_lp_done": NO,
-                            "cm_sx_bloods_taken": BloodTests.objects.filter(name=NONE),
-                        }
-                    )
                 self.assertFormValidatorNoError(
                     form_validator=self.validate_form_validator(cleaned_data)
                 )
@@ -879,12 +849,14 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
                     any_sx_answer=any_sx_answer,
                     cm_sx_answer=cm_sx_answer,
                 ):
-                    cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms()
+                    cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms(
+                        assessment_type=TELEPHONE if any_sx_answer == UNKNOWN else IN_PERSON
+                    )
                     cleaned_data.update(
                         {
                             "any_sx": any_sx_answer,
-                            "current_sx": self.get_non_yes_sx_selection(any_sx_answer),
-                            "current_sx_gte_g3": self.get_non_yes_sx_selection(any_sx_answer),
+                            "current_sx": SiSx.objects.filter(name=NOT_APPLICABLE),
+                            "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
                             "cm_sx": cm_sx_answer,
                         }
                     )
@@ -899,206 +871,6 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
                         form_validator=self.validate_form_validator(cleaned_data)
                     )
 
-    def test_cm_sx_lp_done_applicable_if_cm_sx_yes(self):
-        cleaned_data = self.get_valid_patient_with_cm_symptoms()
-        cleaned_data.update(
-            {
-                "cm_sx": YES,
-                "cm_sx_lp_done": NOT_APPLICABLE,
-            }
-        )
-        self.assertFormValidatorError(
-            field="cm_sx_lp_done",
-            expected_msg="This field is applicable.",
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        for answer in [YES, NO]:
-            with self.subTest(answer=answer):
-                cleaned_data.update({"cm_sx_lp_done": answer})
-                self.assertFormValidatorNoError(
-                    form_validator=self.validate_form_validator(cleaned_data)
-                )
-
-    def test_cm_sx_lp_done_not_applicable_if_cm_sx_not_yes(self):
-        for cm_sx_answer in [NO, NOT_APPLICABLE]:
-            for cm_sx_lp_done_answer in [YES, NO]:
-                with self.subTest(
-                    cm_sx_answer=cm_sx_answer,
-                    cm_sx_lp_done_answer=cm_sx_lp_done_answer,
-                ):
-                    cleaned_data = (
-                        self.get_valid_patient_with_signs_or_symptoms()
-                        if cm_sx_answer == NO
-                        else self.get_valid_patient_any_sx_unknown()
-                    )
-                    cleaned_data.update(
-                        {
-                            "cm_sx": cm_sx_answer,
-                            "cm_sx_lp_done": cm_sx_lp_done_answer,
-                        }
-                    )
-                    self.assertFormValidatorError(
-                        field="cm_sx_lp_done",
-                        expected_msg="This field is not applicable",
-                        form_validator=self.validate_form_validator(cleaned_data),
-                    )
-
-                    cleaned_data.update({"cm_sx_lp_done": NOT_APPLICABLE})
-                    self.assertFormValidatorNoError(
-                        form_validator=self.validate_form_validator(cleaned_data)
-                    )
-
-    def test_cm_sx_bloods_taken_not_applicable_if_cm_sx_not_yes(self):
-        cleaned_data = self.get_valid_patient_with_signs_or_symptoms()
-        cleaned_data.update(
-            {"cm_sx_bloods_taken": BloodTests.objects.filter(name="chemistry")}
-        )
-        self.assertFormValidatorError(
-            field="cm_sx_bloods_taken",
-            expected_msg="This field is not applicable",
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update({"cm_sx_bloods_taken": BloodTests.objects.filter(name=NONE)})
-        self.assertFormValidatorError(
-            field="cm_sx_bloods_taken",
-            expected_msg="This field is not applicable",
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update(
-            {"cm_sx_bloods_taken": BloodTests.objects.filter(name=NOT_APPLICABLE)}
-        )
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data)
-        )
-
-    def test_cm_sx_bloods_taken_applicable_if_cm_sx_is_yes(self):
-        cleaned_data = self.get_valid_patient_with_cm_symptoms()
-        cleaned_data.update(
-            {"cm_sx_bloods_taken": BloodTests.objects.filter(name=NOT_APPLICABLE)}
-        )
-        self.assertFormValidatorError(
-            field="cm_sx_bloods_taken",
-            expected_msg="This field is applicable",
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update({"cm_sx_bloods_taken": BloodTests.objects.filter(name=NONE)})
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update(
-            {"cm_sx_bloods_taken": BloodTests.objects.filter(name="chemistry")}
-        )
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-    def test_cm_sx_bloods_taken_allows_multiple_selections(self):
-        cleaned_data = self.get_valid_patient_with_cm_symptoms()
-        cleaned_data.update(
-            {
-                "cm_sx_bloods_taken": BloodTests.objects.filter(
-                    Q(name="chemistry") | Q(name="hematology") | Q(name=OTHER)
-                ),
-                "cm_sx_bloods_taken_other": "Some other bloods...",
-            }
-        )
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data)
-        )
-
-    def test_cm_sx_bloods_taken_single_selection_only_for_none(self):
-        cleaned_data = self.get_valid_patient_with_cm_symptoms()
-        cleaned_data.update(
-            {
-                "cm_sx_bloods_taken": BloodTests.objects.filter(
-                    Q(name=NONE) | Q(name="chemistry")
-                )
-            }
-        )
-        self.assertFormValidatorError(
-            field="cm_sx_bloods_taken",
-            expected_msg=(
-                "Invalid combination. "
-                "'--No bloods taken' may not be combined with other selections"
-            ),
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update({"cm_sx_bloods_taken": BloodTests.objects.filter(Q(name=NONE))})
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data)
-        )
-
-    def test_cm_sx_bloods_taken_single_selection_only_for_na(self):
-        cleaned_data = self.get_valid_patient_with_signs_or_symptoms()
-        cleaned_data.update(
-            {
-                "cm_sx": NO,
-                "cm_sx_bloods_taken": BloodTests.objects.filter(
-                    Q(name=NOT_APPLICABLE) | Q(name="chemistry")
-                ),
-            }
-        )
-        self.assertFormValidatorError(
-            field="cm_sx_bloods_taken",
-            expected_msg=(
-                "Invalid combination. "
-                "'--Not applicable (if no signs or symptoms related to CM)' "
-                "may not be combined with other selections"
-            ),
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update(
-            {"cm_sx_bloods_taken": BloodTests.objects.filter(Q(name=NOT_APPLICABLE))}
-        )
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data)
-        )
-
-    def test_cm_sx_bloods_taken_other_required_if_other_selected(self):
-        cleaned_data = self.get_valid_patient_with_cm_symptoms()
-        cleaned_data.update(
-            {
-                "cm_sx_bloods_taken": BloodTests.objects.filter(name=OTHER),
-                "cm_sx_bloods_taken_other": "",
-            }
-        )
-        self.assertFormValidatorError(
-            field="cm_sx_bloods_taken_other",
-            expected_msg="This field is required.",
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update({"cm_sx_bloods_taken_other": "Some other blood test"})
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data)
-        )
-
-    def test_cm_sx_bloods_taken_other_not_required_if_other_not_selected(self):
-        cleaned_data = self.get_valid_patient_with_cm_symptoms()
-        cleaned_data.update(
-            {
-                "cm_sx_bloods_taken": BloodTests.objects.filter(name="chemistry"),
-                "cm_sx_bloods_taken_other": "Some other blood test",
-            }
-        )
-        self.assertFormValidatorError(
-            field="cm_sx_bloods_taken_other",
-            expected_msg="This field is not required.",
-            form_validator=self.validate_form_validator(cleaned_data),
-        )
-
-        cleaned_data.update({"cm_sx_bloods_taken_other": ""})
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data)
-        )
-
 
 @tag("sas")
 class TestSignsAndSymptomsStatusReportingFieldsetFormValidation(
@@ -1123,19 +895,30 @@ class TestSignsAndSymptomsStatusReportingFieldsetFormValidation(
         cleaned_data.update(
             {
                 "reportable_as_ae": NO,
-                "current_sx_gte_g3": SiSx.objects.filter(name=NONE),
+                "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
             }
         )
         self.assertFormValidatorNoError(
             form_validator=self.validate_form_validator(cleaned_data)
         )
 
-    def test_reportable_as_ae_not_required_at_d14(self):
-        cleaned_data = self.get_valid_patient_any_sx_unknown()
-        cleaned_data.update({"reportable_as_ae": NOT_APPLICABLE})
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data)
+    def test_reportable_as_ae_not_required_if_sx_unknown_at_d14(self):
+        cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms(
+            visit_code=DAY14, assessment_type=TELEPHONE
         )
+        cleaned_data.update(
+            {
+                "any_sx": UNKNOWN,
+                "current_sx": SiSx.objects.filter(name=NOT_APPLICABLE),
+                "current_sx_gte_g3": SiSx.objects.filter(name=NOT_APPLICABLE),
+                "reportable_as_ae": NOT_APPLICABLE,
+            }
+        )
+        form_validator = SignsAndSymptomsFormValidator(cleaned_data=cleaned_data)
+        try:
+            form_validator.validate()
+        except forms.ValidationError as e:
+            self.fail(f"ValidationError unexpectedly raised. Got {e}")
 
     def test_patient_admitted_allowed_at_d14(self):
         cleaned_data = self.get_valid_patient_with_signs_or_symptoms(visit_code=DAY14)
